#!/bin/bash
# packager           : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# homepage           : http://www.t2-project.org/packages/libglpng.html
# source location    : http://slackbuilds.org/sources/12.2/libglpng-1.45.tar.bz2
# last revised       : 13.9.2009
# dep                : 

softname='libglpng'
softversion='1.45'
packageversion='64.1'

arch='i486'
cpu='i686'

# log ;)
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.bz2"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://slackbuilds.org/sources/12.2/$softname-$softversion.tar.bz2

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
        |-----handy-ruler------------------------------------------------------|
libglpng: libglpng  (PNG loader for OpenGL)
libglpng: 
libglpng: glpng is a small toolkit to make loading PNG image files as an
libglpng: OpenGL texture as easy as possible.
libglpng:
libglpng:
libglpng:
libglpng:
libglpng:
libglpng:
libglpng:
EOF

# check if source is present
if [ -f $softname-$softversion.bz2 ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xvf $srcpkg
cd $src

# build
    export CFLAGS="-O2 -march=$arch -mtune=$cpu"
    export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
  
    patch -p1 < $src/libglpng-1.45-extra_cflags.patch

    make EXTRA_CFLAGS="$CFLAGS"
    make install DOCDIR=$dest/usr/doc/$softname-$softversion DESTDIR=$dest/usr
    
# add 'default' files
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      glpng.htm\
      $dest/usr/doc/$softname-$softversion
        
# strip executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# compress man pages
( cd $dest/usr/man
  find . -name "*.?" | xargs gzip -9
)

# ZenBuild
cp $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion
cp $buildir/libglpng-1.45-extra_cflags.patch $dest/usr/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work:
cd $dest
makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "libX11,libXau,libXdamage,libXdmcp,libXext,libXfixes,\
libXxf86vm,libdrm,libpng,libxcb,mesa,zlib" > $package.dep

# src file
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/l/libglpng/source/build-libglpng.sh > $package.src
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/l/libglpng/source/libglpng-1.45-extra_cflags.patch >> $package.src
echo $source >> $package.src

# erase
rm -rf $src
rm -rf $dest

# log ;)
) 2>&1 | tee "$softname-$softversion-build.log"
